package com.muyu.marketing.domain.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.ActivityTeamInfo;
import com.muyu.marketing.domain.resp.ActivityTeamInfoQueryResp;
import com.muyu.marketing.domain.resp.TeamProjectSkuInfoSkuResp;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;


@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@EqualsAndHashCode(callSuper = true)
public class ActivityTeamInfoQueryModel extends BaseEntity {
    /**
     * 拼团名称
     */
    private String name;
    /**
     * 商品ID
     */
    private Long productId;
    /**
     * 商品活动图
     */
    private String productImage;
    /**
     * 商品名称
     */
    private String productName;
    /**
     * 活动简介
     */
    private String introduction;
    /**
     * 单位
     */

    private String unit;
    /**
     * 轮播图
     */

    private String imageList;
    /**
     * 活动结束时间
     */
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    private Date endTime;
    /**
     * 活动排序
     */
    private Long sort;
    /**
     * 商品SkU集合
     */
    private List<TeamProjectSkuInfoSkuResp> projectSkuInfoAddRespList;
    /**
     * 活动详情
     */
    private String content;
    /**
     * 活动状态
     */
    private String status;
    /**
     * 策略类型
     */
    private String strategyType;
    /**
     * 策略ID
     */
    private Long strategyId;

    public static ActivityTeamInfoQueryModel buildModel(ActivityTeamInfo activityTeamInfo, String productName, List<TeamProjectSkuInfoSkuResp> projectSkuInfoAddRespList) {
        return ActivityTeamInfoQueryModel.builder()
                .name(activityTeamInfo.getName())
                .productId(activityTeamInfo.getProductId())
                .productImage(activityTeamInfo.getProductImage())
                .introduction(activityTeamInfo.getIntroduction())
                .unit(activityTeamInfo.getUnit())
                .imageList(activityTeamInfo.getImageList())
                .endTime(activityTeamInfo.getEndTime())
                .sort(activityTeamInfo.getSort())
                .content(activityTeamInfo.getContent())
                .status(activityTeamInfo.getStatus())
                .strategyType(activityTeamInfo.getStrategyType())
                .strategyId(activityTeamInfo.getStrategyId())
                .projectSkuInfoAddRespList(projectSkuInfoAddRespList)
                .productName(productName)
                .build();
    }



}
